@@ -34,8 +34,8 @@ bool AutomateDeterministe::inclus_dans(const AutomateDeterministeSP& automate) c
 		}
 		for(auto& l:_transitions[e.first])
 		{
-			RegexParametresElementSP lc;
-			for(lc = l.first->copie() ; static_cast<bool>(lc) ; lc = lc->joker())
+			RegexParametresElementCSP& lc = const_cast<RegexParametresElementCSP&>(l.first);
+			for( ; static_cast<bool>(lc) ; lc = lc->joker())
 			{
 				auto it = automate->_transitions[e.second].find(lc);
 				if(it!=automate->_transitions[e.second].end())
@@ -49,8 +49,7 @@ bool AutomateDeterministe::inclus_dans(const AutomateDeterministeSP& automate) c
 				}
 				if(not l.first->_modifiable)
 					continue;
-				lc->_modifiable = false;
-				it = automate->_transitions[e.second].find(lc);
+				it = automate->_transitions[e.second].find(lc->version_non_modifiable());
 				if(it!=automate->_transitions[e.second].end())
 				{
 					auto ne = std::make_pair(l.second,it->second);
@@ -60,7 +59,6 @@ bool AutomateDeterministe::inclus_dans(const AutomateDeterministeSP& automate) c
 					}
 					break;
 				}
-				lc->_modifiable = true;
 			}
 			if(not lc)
 			{
@@ -78,9 +76,9 @@ ConformiteAutomate AutomateDeterministe::conforme(const std::vector<RegexParamet
 	for(auto& v: valeurs)
 	{
 		++indice_valeur;
-		RegexParametresElementSP lettre;
+		RegexParametresElementCSP& lettre = const_cast<RegexParametresElementCSP&>(v);
 		bool ok = false;
-		for(lettre = v->copie() ; static_cast<bool>(lettre) ; lettre=lettre->joker())
+		for( ; static_cast<bool>(lettre) ; lettre=lettre->joker())
 		{
 			//AutomateDeterministe::chronometre_recherche_base().debut();
 			auto it = _transitions[etat_courant].find(lettre);
@@ -93,9 +91,8 @@ ConformiteAutomate AutomateDeterministe::conforme(const std::vector<RegexParamet
 			}
 			if(not v->_modifiable)
 				continue;
-			lettre->_modifiable = false;
 			//AutomateDeterministe::chronometre_recherche_constante().debut();
-			it = _transitions[etat_courant].find(lettre);
+			it = _transitions[etat_courant].find(lettre->version_non_modifiable());
 			//AutomateDeterministe::chronometre_recherche_constante().fin();
 			if(it!=_transitions[etat_courant].end())
 			{
@@ -103,7 +100,6 @@ ConformiteAutomate AutomateDeterministe::conforme(const std::vector<RegexParamet
 				etat_courant = it->second;
 				break;
 			}
-			lettre->_modifiable = true;	
 		}
 		if(not ok)
 		{
